@@ -5,15 +5,17 @@
 
 __author__ = """MIT Data To AI Lab"""
 __email__ = 'dailabmit@gmail.com'
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 import numpy as np
 import pandas as pd
 
+from rdt import transformers
 from rdt.hyper_transformer import HyperTransformer
 
 __all__ = [
     'HyperTransformer',
+    'transformers'
 ]
 
 
